import { Request, Response } from 'express';
import UserService from '../services/User';

export async function registerUser(req: Request, res: Response): Promise<void> {
    const { username, password } = req.body;
    try {
        await UserService.createUser(username, password);
        res.status(201).send('User registered');
    } catch (error) {
        console.error('Error registering user:', error);
        res.status(500).send('Error registering user');
    }
}

export async function loginUser(req: Request, res: Response): Promise<void> {
    const { username, password } = req.body;
    try {
        const isValid = await UserService.validateUserCredentials(username, password);
        if (isValid) {
            res.send('Login successful');
        } else {
            res.status(401).send('Invalid credentials');
        }
    } catch (error) {
        console.error('Error validating credentials:', error);
        res.status(500).send('Error validating credentials');
    }
}
